mul
###

.. doxygenfunction:: librapid::Array::operator*(const Array &other) const

---

.. doxygenfunction:: librapid::mul(const Array &a, const Array &b)

---

.. doxygenfunction:: librapid::mul(const Array &a, const Array &b, Array &res)
